package com.jz.agent.client.service;


import com.google.gson.Gson;
import com.jcraft.jsch.*;
import com.jz.agent.client.DmpDsAgentClient;
import com.jz.dmp.agent.DmpAgentResult;
import com.jz.dmp.agent.ResultCode;
import com.jz.dmp.modules.model.DmpAgentDatasourceInfo;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPFile;
import org.apache.commons.net.ftp.FTPReply;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.io.InputStream;
import java.util.*;

public class DmpFtpAgentClientService implements DmpDsAgentClient {
	
	private Gson gson = new Gson();
	private static Logger logger = LoggerFactory.getLogger(DmpFtpAgentClientService.class);

	@SuppressWarnings("unused")
	public DmpAgentResult testConnect(DmpAgentDatasourceInfo ds) {
		if ("ftp".equals(ds.getProtocol())) {
			return testFtpConnect(ds);
		} else {
			return testSftpConnect(ds);
		}
	}

	public DmpAgentResult getTableNameList(DmpAgentDatasourceInfo ds) {
		List<String> list = new ArrayList<String>();
		return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(list));
	}

	@SuppressWarnings("unchecked")
	public DmpAgentResult getTableColumnList(DmpAgentDatasourceInfo ds, String filePath) {
		Object o = this.getColumnAndResult(ds, filePath);
		if(o instanceof Map) {
			Map<String, Object> m = (Map<String, Object>) o;
			List<Map<String, Object>> l = (List<Map<String, Object>>) m.get("column");
			return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(l));
		} else {
			return new DmpAgentResult(ResultCode.EXCEPTION, gson.toJson(o));
		}
	}

	@SuppressWarnings({ "unused"})
	public DmpAgentResult previewData(DmpAgentDatasourceInfo ds, String filePath) {
		Object o = this.getColumnAndResult(ds, filePath);
		if(o instanceof Map) {
			Map<String, Object> m = (Map<String, Object>) o;
			m.remove("column");
			return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(m));
		} else {
			return new DmpAgentResult(ResultCode.EXCEPTION, gson.toJson(o));
		}
	}
	
	@SuppressWarnings({ "unused", "unchecked" })
	private Object getColumnAndResult(DmpAgentDatasourceInfo ds, String filePath) {
		Map<String, Object> map = new HashMap<String, Object>();
		
		String remotePath = "";
		String fileName = "";
		
		if(StringUtils.isNotBlank(filePath)) {
			try {
				remotePath = filePath.substring(0, filePath.lastIndexOf("/"));
				fileName = filePath.substring(filePath.lastIndexOf("/")+1, filePath.length());
			} catch(Exception e) {
				return new DmpAgentResult(ResultCode.PARAMS_ERROR, "参数错误：filePath="+filePath);
			}
		} else {
			return new DmpAgentResult(ResultCode.PARAMS_ERROR, "参数错误：filePath="+filePath);
		}
		String splitSymbol = ds.getDelimiter();
		String fileType = ds.getFileType();
		int columnNum = 0;
		InputStream is = null;
		if ("ftp".equals(ds.getProtocol())) {
			boolean result = false;
			FTPClient ftp = new FTPClient();
			try {
				int reply;
				ftp.connect(ds.getHost(), Integer.valueOf(ds.getPort()).intValue());
				ftp.login(ds.getUserName(), ds.getPassword());
				reply = ftp.getReplyCode();
				if (!FTPReply.isPositiveCompletion(reply)) {
					ftp.disconnect();
					return new DmpAgentResult(ResultCode.INTERNAL_SERVER_ERROR, "FTP不能连接");
				}
				ftp.changeWorkingDirectory(remotePath);
				FTPFile[] fs = ftp.listFiles();
				for (FTPFile ff : fs) {
					if (ff.getName().equals(fileName)) {
						//File localFile = new File(localPath + "\\" + ff.getName());
						/*OutputStream os = new FileOutputStream(localFile);
						ftp.retrieveFile(ff.getName(), os);*/
						is = ftp.retrieveFileStream(filePath);
						StringBuilder sb = new StringBuilder();
						int rowCnt = 0;
						int rowNum = 6;
						byte[] bs = new byte[1024*50];
			            int len = -1;
			            List<String> header = new ArrayList<String>();
			            List<String> type = new ArrayList<String>();
			            while((len = is.read(bs)) != -1){
			                sb.append(new String(bs,0,len));
			                /*Pattern p = Pattern.compile("\\s*|\t|\r\n|\r|\n");      
			                Matcher m = p.matcher(sb.toString()); 
			                while(m.find()) {
			                	System.out.println(m.group()); 
			                }*/
			                //System.out.println(m.groupCount());
			                //char[] c = System.getProperty("line.separator").toCharArray();
				            //System.out.println(System.getProperty("line.separator").toCharArray());
			                String s = sb.toString();
			                List<Object[]> list = new ArrayList<Object[]>();
			                boolean flag = true;
			                String enterLine = "\n";
			                if(s.indexOf("\r\n") > -1) {
			                	enterLine = "\r\n";
			                } else if(s.indexOf("\r") > -1) {
			                	enterLine = "\r";
			                } else if(s.indexOf("\n") > -1) {
			                	enterLine = "\n";
			                } else {
			                	flag = false;
			                }
			                while(rowCnt < rowNum && flag) {
				                int i1 = s.indexOf(enterLine);
				                String tmp = s.substring(0, i1);
				                if("json".equalsIgnoreCase(fileType)) {
				                	Map<String, Object> m = gson.fromJson(tmp, Map.class);
				                	if(rowCnt == 0) {
				                		for(Map.Entry<String, Object> me : m.entrySet()) {
				                			header.add(me.getKey());
				                			type.add(this.getObjectType(me.getValue()));
				                			columnNum++;
				                		}
				                	}
				                	Object[] row = new Object[columnNum];
				                	int i = 0;
				                	for(String rn : header) {
				                		row[i] = m.get(rn);
				                		i++;
				                	}
				                	list.add(row);
				                } else {
				                	if(StringUtils.isBlank(splitSymbol)) {
					                	if(tmp.indexOf(",") > -1) {
						                	splitSymbol = ",";
						                } else if(tmp.indexOf("\t") > -1) {
						                	splitSymbol = "\t";
						                } else if(tmp.indexOf(" ") > -1) {
						                	splitSymbol = " ";
						                }
					                }
					                String[] tArr = tmp.split(splitSymbol);
					                list.add(tArr);
					                columnNum = tArr.length;
				                }
				                s = s.substring(i1+2, s.length());
				                rowCnt++;
			                }
			                if(rowCnt == rowNum) {
			                	map.put("result", list);
			                	break;
			                } else {
			                	rowCnt = 0;
								rowNum = 6;
			                }
			            }
						//os.close();
						break;
					}
				}
				ftp.logout();
			} catch (IOException e) {
				e.printStackTrace();
				return new DmpAgentResult(ResultCode.EXCEPTION, "FTP读取信息异常："+e.getMessage());
			} finally {
				if (ftp.isConnected()) {
					try {
						ftp.disconnect();
					} catch (IOException ioe) {
					}
				}
				if(is != null)
					try {
						is.close();
					} catch (IOException e) {
						e.printStackTrace();
					}
			}
			
		} else {
			String host = ds.getHost();
			int port = Integer.valueOf(ds.getPort()).intValue();
			String username = ds.getUserName();
			String password = ds.getPassword();
			ChannelSftp sftp = null;
			Session session = null;
			try {
				JSch jsch = new JSch();
				session = jsch.getSession(username, host, port);
				if (password != null) {
					session.setPassword(password);
				}
				Properties config = new Properties();
				config.put("StrictHostKeyChecking", "no");
				session.setConfig(config);
				session.connect();
				Channel channel = session.openChannel("sftp");
				channel.connect();
				sftp = (ChannelSftp) channel;
				
				if (remotePath != null && !"".equals(remotePath)) {  
		            sftp.cd(remotePath);  
		        }  
				is = sftp.get(fileName);  
				StringBuilder sb = new StringBuilder();
				int rowCnt = 0;
				int rowNum = 6;
				byte[] bs = new byte[1024*50];
	            int len = -1;
	            List<String> header = new ArrayList<String>();
	            List<String> type = new ArrayList<String>();
	            while((len = is.read(bs)) != -1){
	                sb.append(new String(bs,"UTF-8"));
	                String s = sb.toString();
	                s = s.replaceAll("\\ufeff", "");
	                List<Object[]> list = new ArrayList<Object[]>();
	                boolean flag = true;
	                String enterLine = "\n";
	                if(s.indexOf("\r\n") > -1) {
	                	enterLine = "\r\n";
	                } else if(s.indexOf("\r") > -1) {
	                	enterLine = "\r";
	                } else if(s.indexOf("\n") > -1) {
	                	enterLine = "\n";
	                } else {
	                	flag = false;
	                }
	                while(rowCnt < rowNum && flag) {
		                int i1 = s.indexOf(enterLine);
		                String tmp = s.substring(0, i1);
		                if("json".equalsIgnoreCase(fileType)) {
		                	Map<String, Object> m = gson.fromJson(tmp, Map.class);
		                	if(rowCnt == 0) {
		                		for(Map.Entry<String, Object> me : m.entrySet()) {
		                			header.add(me.getKey());
		                			type.add(this.getObjectType(me.getValue()));
		                			columnNum++;
		                		}
		                	}
		                	Object[] row = new Object[columnNum];
		                	int i = 0;
		                	for(String rn : header) {
		                		row[i] = m.get(rn);
		                		i++;
		                	}
		                	list.add(row);
		                } else {
		                	if(StringUtils.isBlank(splitSymbol)) {
			                	if(tmp.indexOf(",") > -1) {
				                	splitSymbol = ",";
				                } else if(tmp.indexOf("\t") > -1) {
				                	splitSymbol = "\t";
				                } else if(tmp.indexOf(" ") > -1) {
				                	splitSymbol = " ";
				                }
			                }
			                String[] tArr = tmp.split(splitSymbol);
			                list.add(tArr);
			                columnNum = tArr.length;
		                }
		                s = s.substring(i1+2, s.length());
		                rowCnt++;
	                }
	                if(rowCnt == rowNum) {
	                	map.put("result", list);
	                	break;
	                } else {
	                	rowCnt = 0;
						rowNum = 3;
	                }
	            }
	            
	            List<Map<String, Object>> l2 = new ArrayList<Map<String, Object>>();
	            List<String> l3 = new ArrayList<String>();
	            if("json".equalsIgnoreCase(fileType)) {
	            	for(int i = 0; i < header.size(); i++) {
	            		Map<String, Object> m = new HashMap<String, Object>();
	            		m.put("key", i);
	        			m.put("name", header.get(i));
	        			m.put("type", type.get(i));
	        			l2.add(m);
	        			l3.add(header.get(i).toUpperCase());
	            	}
	            } else {
	            	if("1".equals(ds.getIsHaveHeader())){
	                	List<String[]> l = (List<String[]>) map.get("result");
	                	String[] arr = l.get(0);
	                	for(int i = 0; i < columnNum; i++) {
	            			Map<String, Object> m = new HashMap<String, Object>();
	            			m.put("key", i);
	            			m.put("name", arr[i]);
	            			m.put("type", "STRING");
	            			l2.add(m);
	            			l3.add(arr[i].toUpperCase());
	            		}
	                	map.put("result", l.subList(1, l.size()));
	                } else {
	                	for(int i = 0; i < columnNum; i++) {
	            			Map<String, Object> m = new HashMap<String, Object>();
	            			m.put("key", i);
	            			m.put("name", "第"+i+"列");
	            			m.put("type", "STRING");
	            			l2.add(m);
	            			l3.add("第"+i+"列");
	            		}
	                }
	            }
	            map.put("header", l3);
	            map.put("column", l2);
			} catch (JSchException e) {
				e.printStackTrace();
				return new DmpAgentResult(ResultCode.EXCEPTION, "SFTP读取信息异常："+e.getMessage());
			} catch (SftpException e) {
				e.printStackTrace();
				return new DmpAgentResult(ResultCode.EXCEPTION, "SFTP读取信息异常："+e.getMessage());
			} catch (IOException e) {
				e.printStackTrace();
				return new DmpAgentResult(ResultCode.EXCEPTION, "SFTP读取信息异常："+e.getMessage());
			} finally {
				if (sftp != null) {
					if (sftp.isConnected()) {
						sftp.disconnect();
					}
				}
				if (session != null) {
					if (session.isConnected()) {
						session.disconnect();
					}
				}
			}
		}
		return map;
	}
	
	private String getObjectType(Object obj) {
		String t = null;
		if(obj instanceof Long) {
			t = "LONG";
		} else if(obj instanceof Double) {
			t = "DOUBLE";
		} else if(obj instanceof Boolean) {
			t = "BOOLEAN";
		} else if(obj instanceof Date) {
			t = "DATE";
		} else {
			t = "STRING";
		}
		return t;
	}

	private DmpAgentResult testFtpConnect(DmpAgentDatasourceInfo ds) {
		String host = ds.getHost();
		int port = Integer.valueOf(ds.getPort()).intValue();
		String username = ds.getUserName();
		String password = ds.getPassword();
		boolean result = false;
		FTPClient ftp = new FTPClient();
		try {
			int reply;
			ftp.connect(host, port);
			ftp.login(username, password);
			reply = ftp.getReplyCode();
			if (!FTPReply.isPositiveCompletion(reply)) {
				result = false;
			} else {
				result = true;
			}
			ftp.disconnect();
			return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(result));
		} catch (IOException e) {
			e.printStackTrace();
			return new DmpAgentResult(ResultCode.SUCCESS, "FTP连通性测试异常："+e.getMessage());
		} finally {
			if (ftp.isConnected()) {
				try {
					ftp.disconnect();
				} catch (IOException ioe) {
				}
			}
		}
	}

	private DmpAgentResult testSftpConnect(DmpAgentDatasourceInfo ds) {
		ChannelSftp sftp = null;
		Session session = null;
		String host = ds.getHost();
		int port = Integer.valueOf(ds.getPort()).intValue();
		String username = ds.getUserName();
		String password = ds.getPassword();
		try {
			JSch jsch = new JSch();
			session = jsch.getSession(username, host, port);
			if (password != null) {
				session.setPassword(password);
			}
			Properties config = new Properties();
			config.put("StrictHostKeyChecking", "no");
			session.setConfig(config);
			session.connect();
			Channel channel = session.openChannel("sftp");
			channel.connect();
			sftp = (ChannelSftp) channel;
			return new DmpAgentResult(ResultCode.SUCCESS, "true");
		} catch (JSchException e) {
			e.printStackTrace();
			return new DmpAgentResult(ResultCode.SUCCESS, "SFTP连通性测试异常："+e.getMessage());
		} finally {
			if (sftp != null) {
				if (sftp.isConnected()) {
					sftp.disconnect();
				}
			}
			if (session != null) {
				if (session.isConnected()) {
					session.disconnect();
				}
			}
		}
	}
	
	
	@SuppressWarnings("unused")
	private void unzip() {
		
	}

}
