package com.jz.dmp.modules.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.utils.DateUtils;
import com.jz.common.utils.web.HttpClientUtils;
import com.jz.common.utils.web.SessionUtils;
import com.jz.dmp.modules.controller.DataIntegration.bean.SourceDbNameListDto;
import com.jz.dmp.modules.controller.dataService.bean.ApiInterfaceInfoListReq;
import com.jz.dmp.modules.controller.dataService.bean.ApiInterfaceReq;
import com.jz.common.constant.GatewayApiConstant;
import com.jz.dmp.modules.controller.dataService.bean.CreateFolderReq;
import com.jz.dmp.modules.controller.dataService.bean.MakeBigDataApiReq;
import com.jz.dmp.modules.dao.OfflineSynchDao;
import com.jz.dmp.modules.service.DmpApiServiceMangeService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @ClassName: DmpApiServiceMangeServiceImpl
 * @Description: 数据服务-服务管理--调用gateway 接口
 * @Author: Bellamy
 * @Date 2021/1/19
 * @Version 1.0
 */
@Service("dmpApiServiceMangeService")
public class DmpApiServiceMangeServiceImpl implements DmpApiServiceMangeService {

    private static Logger logger = LoggerFactory.getLogger(DmpApiServiceMangeServiceImpl.class);

    @Value("${spring.gateway-url}")
    private String gatewayUrl;

    @Value("${spring.api-bigData-setting}")
    private String apiBigSetting;

    @Autowired
    private OfflineSynchDao offlineSynchDao;

    /**
     * 保存/编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult saveApiInfo(ApiInterfaceReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.addApiInfo;
        req.setCreateUser(SessionUtils.getCurrentUserName());
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 制作/编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult saveApiBigDataInfo(ApiInterfaceReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.addApiBigData;

        req.setCreateUser(SessionUtils.getCurrentUserName());
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    @Override
    public JsonResult updateApiInfo(ApiInterfaceReq req) throws Exception {
        JsonResult result = new JsonResult();
        String url = gatewayUrl + GatewayApiConstant.updateApiInfo;

        req.setCreateUser(SessionUtils.getCurrentUserName());
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("编辑失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return result;
            }
        }
        if (jsonObject.containsKey("msg")) {
            logger.info(jsonObject.get("msg").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("msg").toString());
        }
        return result;
    }

    /**
     * 编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    @Override
    public JsonResult updateApiBigDataInfo(MakeBigDataApiReq req) throws Exception {
        ApiInterfaceReq baseApi = new ApiInterfaceReq();
        BeanUtils.copyProperties(req, baseApi);
        //编辑API基本信息
        JsonResult baseRes = updateApiInfo(baseApi);
        if (!"200".equals(baseRes.getCode())) {
            throw new RuntimeException(baseRes.getMessage());
        }

        //编辑API(大数据查询/标签查询)
        JsonResult result = new JsonResult();
        req.setCreateUser(SessionUtils.getCurrentUserName());
        String url = gatewayUrl + GatewayApiConstant.addApiBigData;
        String resultData = HttpClientUtils.post(url, JSONObject.toJSONString(req));
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("编辑失败！");
        }
        logger.info("#################响应结果数据{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return result;
            }
        }
        if (jsonObject.containsKey("msg")) {
            logger.info(jsonObject.get("msg").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(jsonObject.get("msg").toString());
        }
        return result;
    }

    /**
     * API计量调用次数和执行时长
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    @Override
    public JsonResult getCountAPiCallStat() throws Exception {
        String url = gatewayUrl + GatewayApiConstant.countAPiCallStat;
        Map params = new HashMap();
        params.put("date", DateUtils.currentDate());
        JsonResult result = GatewayApiConstant.getRequest2GetData(url, params);
        return result;
    }

    /**
     * 获取数据源库——下拉框
     *
     * @return
     * @author Bellamy
     */
    @Override
    public JsonResult querygSourceDbList(Integer projectId, String dbName) throws Exception {
        Map map = new HashMap();
        map.put("projectId", projectId); //项目id
        map.put("dbName", dbName);
        List<SourceDbNameListDto> list = offlineSynchDao.querygSourceDbList(map);
        return JsonResult.ok(list);
    }

    /**
     * 配置数据源——下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-21
     */
    @Override
    public JsonResult getSourceSetting() throws Exception {
        String[] arr = apiBigSetting.split(",");
        List<String> list = Arrays.asList(arr);
        return JsonResult.ok(list);
    }

    /**
     * API计量--API未调用列表
     *
     * @author Bellamy
     * @since 2021-01-22
     */
    @Override
    public JsonResult queryApiNotCalledListPage(ApiInterfaceInfoListReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.notCalledList;
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * API计量--API已调用列表
     *
     * @param req
     * @author Bellamy
     * @since 2021-02-25
     */
    @Override
    public JsonResult listCallApi(ApiInterfaceInfoListReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.listCallApi;
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 服务开发---获取ApiId
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @Override
    public JsonResult getApiId() throws Exception {
        String url = gatewayUrl + GatewayApiConstant.getApiId;
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, "");
        return result;
    }

    /**
     * 创建项目文件夹
     *
     * @param req
     * @author Bellamy
     * @since 2021-02-24
     */
    @Override
    public JsonResult createProjectFolder(CreateFolderReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.createProjectFolder;
        req.setCreateUser(SessionUtils.getCurrentUserName());
        if (StringUtils.isNotEmpty(req.getId())) {
            req.setUpdateUser(SessionUtils.getCurrentUserName());
        }
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 删除文件夹
     *
     * @param id
     * @return
     * @author Bellamy
     * @since 2021-03-3
     */
    @Override
    public JsonResult delFolderById(String id) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.delFolder;
        Map params = new HashMap();
        params.put("id", id);
        JsonResult result = GatewayApiConstant.getRequest2GetData(url, params);
        return result;
    }

    /**
     * 获取function模板列表
     *
     * @return
     * @author Bellamy
     * @since 2021-03-3
     */
    @Override
    public JsonResult getFunctionTemplateList() throws Exception {
        String url = gatewayUrl + GatewayApiConstant.functionTemplate;
        Map params = new HashMap();
        JsonResult result = GatewayApiConstant.getRequest2GetData(url, params);
        return result;
    }

    /**
     * 服务开发API列表
     *
     * @param req
     * @author Bellamy
     * @since 2021-02-24
     */
    @Override
    public JsonResult apiListPaging(ApiInterfaceInfoListReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.listServerApplyApi;
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 获取文件夹列表
     *
     * @param projectId
     * @param orgCode
     * @return
     * @author Bellamy
     * @since 2021-02-24
     */
    @Override
    public JsonResult getFolderTree(String projectId, String orgFolder) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.folderTree;

        Map params = new HashMap();
        if (StringUtils.isNotEmpty(projectId)) {
            params.put("projectId", projectId);
        }
        params.put("orgFolder", orgFolder);
        JsonResult result = GatewayApiConstant.getRequest2GetData(url, params);
        return result;
    }

}