package com.jz.dmp.modules.service.projconfig.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectEngineParamBatch;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectEngineParamDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectEngineParamRequest;
import com.jz.dmp.modules.dao.projconfig.DmpProjectEngineParamMapper;
import com.jz.dmp.modules.model.DmpProjectEngineParam;
import com.jz.dmp.modules.service.projconfig.DmpProjectEngineParamService;

/**
 * 计算引擎项目参数表服务的实现?
 * 
 * @author ybz
 *
 */
@Service("dmpProjectEngineParamService")
public class DmpProjectEngineParamServiceImpl extends BaseService implements DmpProjectEngineParamService {

	private static Logger logger = LoggerFactory.getLogger(DmpProjectEngineParamServiceImpl.class);

	@Autowired
	private DmpProjectEngineParamMapper dmpProjectEngineParamMapper;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#findList(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpProjectEngineParamDto> findListWithPage(DmpProjectEngineParamRequest dmpProjectEngineParamRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpProjectEngineParamDto> pageInfoResponse = new PageInfoResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectEngineParamRequest.getProjectParamId() != null) {
			param.put("projectParamId", dmpProjectEngineParamRequest.getProjectParamId());
		}
		//项目配置引擎关系主键
		if (dmpProjectEngineParamRequest.getConfigEngineId() != null) {
			param.put("configEngineId", dmpProjectEngineParamRequest.getConfigEngineId());
		}
		//引擎参数主键
		if (dmpProjectEngineParamRequest.getParamId() != null) {
			param.put("paramId", dmpProjectEngineParamRequest.getParamId());
		}
		//参数名称
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamName())) {
			param.put("paramName", dmpProjectEngineParamRequest.getParamName());
		}
		//参数值
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamValue())) {
			param.put("paramValue", dmpProjectEngineParamRequest.getParamValue());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getRemark())) {
			param.put("remark", dmpProjectEngineParamRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectEngineParamRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectEngineParamRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectEngineParamRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectEngineParamRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectEngineParamRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectEngineParamRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectEngineParamRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectEngineParamRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectEngineParamRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectEngineParamRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectEngineParamRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectEngineParamRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectEngineParamRequest.getUpdateTimeEnd());
		}

		PageHelper.startPage(dmpProjectEngineParamRequest.getPageNum(), dmpProjectEngineParamRequest.getPageSize());
		List<DmpProjectEngineParamDto> list = dmpProjectEngineParamMapper.findList(param);
		PageInfo<DmpProjectEngineParamDto> pageInfo = new PageInfo<>(list);

		pageInfoResponse.setCode(StatuConstant.SUCCESS_CODE);
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#findList(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpProjectEngineParamDto> findList(DmpProjectEngineParamRequest dmpProjectEngineParamRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectEngineParamDto> baseBeanResponse = new BaseBeanResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectEngineParamRequest.getProjectParamId() != null) {
			param.put("projectParamId", dmpProjectEngineParamRequest.getProjectParamId());
		}
		//项目配置引擎关系主键
		if (dmpProjectEngineParamRequest.getConfigEngineId() != null) {
			param.put("configEngineId", dmpProjectEngineParamRequest.getConfigEngineId());
		}
		//引擎参数主键
		if (dmpProjectEngineParamRequest.getParamId() != null) {
			param.put("paramId", dmpProjectEngineParamRequest.getParamId());
		}
		//参数名称
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamName())) {
			param.put("paramName", dmpProjectEngineParamRequest.getParamName());
		}
		//参数值
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamValue())) {
			param.put("paramValue", dmpProjectEngineParamRequest.getParamValue());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getRemark())) {
			param.put("remark", dmpProjectEngineParamRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectEngineParamRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectEngineParamRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectEngineParamRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectEngineParamRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectEngineParamRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectEngineParamRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectEngineParamRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectEngineParamRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectEngineParamRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectEngineParamRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectEngineParamRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectEngineParamRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectEngineParamRequest.getUpdateTimeEnd());
		}

		List<DmpProjectEngineParamDto> list = dmpProjectEngineParamMapper.findList(param);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setDatas(list);
		return baseBeanResponse;
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#add(com.ycxc.vmts.entity.DmpProjectEngineParam,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectEngineParam> add(DmpProjectEngineParam dmpProjectEngineParam, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpProjectEngineParam> baseBeanResponse = new BaseBeanResponse<>();

		/*$*setProjectParamIdCodeReplace*$*/
		// 创建人
		dmpProjectEngineParam.setCreateUserId(getHttpRequestUserId(httpRequest));
		// 创建时间
		dmpProjectEngineParam.setCreateTime(new Date());

		dmpProjectEngineParamMapper.insertSelective(dmpProjectEngineParam);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpProjectEngineParam);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#edit(com.ycxc.vmts.entity.DmpProjectEngineParam,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectEngineParam> edit(DmpProjectEngineParam dmpProjectEngineParam, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpProjectEngineParam> baseBeanResponse = new BaseBeanResponse<>();

		// 修改人
		dmpProjectEngineParam.setUpdateUserId(getHttpRequestUserId(httpRequest));
		// 修改时间
		dmpProjectEngineParam.setUpdateTime(new Date());

		dmpProjectEngineParamMapper.updateByPrimaryKeySelective(dmpProjectEngineParam);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpProjectEngineParam);

		return baseBeanResponse;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#addOrEdit(com.ycxc.vmts.entity.DmpProjectEngineParam,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectEngineParam> addOrEdit(DmpProjectEngineParam dmpProjectEngineParam, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpProjectEngineParam> baseBeanResponse = new BaseBeanResponse<>();
		
		Integer projectParamId = dmpProjectEngineParam.getProjectParamId();
		
		if (null==projectParamId) {//新增
			// 创建人
			dmpProjectEngineParam.setCreateUserId(getHttpRequestUserId(httpRequest));
			// 创建时间
			dmpProjectEngineParam.setCreateTime(new Date());

			dmpProjectEngineParamMapper.insertSelective(dmpProjectEngineParam);

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("新增成功");
			baseBeanResponse.setData(dmpProjectEngineParam);
		} else {//修改
			// 修改人
			dmpProjectEngineParam.setUpdateUserId(getHttpRequestUserId(httpRequest));
			// 修改时间
			dmpProjectEngineParam.setUpdateTime(new Date());

			dmpProjectEngineParamMapper.updateByPrimaryKeySelective(dmpProjectEngineParam);

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("修改成功");
			baseBeanResponse.setData(dmpProjectEngineParam);
		}
		
		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#findById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpProjectEngineParamDto> findById(Integer projectParamId, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectEngineParamDto> baseBeanResponse = new BaseBeanResponse<>();

		DmpProjectEngineParamDto dmpProjectEngineParamDto = dmpProjectEngineParamMapper.findById(projectParamId);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpProjectEngineParamDto);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse deleteById(Integer projectParamId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectEngineParamMapper.deleteByPrimaryKey(projectParamId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDeleteById(Integer projectParamId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectEngineParamMapper.softDeleteByPrimaryKey(projectParamId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse delete(DmpProjectEngineParamRequest dmpProjectEngineParamRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectEngineParamRequest.getProjectParamId() != null) {
			param.put("projectParamId", dmpProjectEngineParamRequest.getProjectParamId());
		}
		//项目配置引擎关系主键
		if (dmpProjectEngineParamRequest.getConfigEngineId() != null) {
			param.put("configEngineId", dmpProjectEngineParamRequest.getConfigEngineId());
		}
		//引擎参数主键
		if (dmpProjectEngineParamRequest.getParamId() != null) {
			param.put("paramId", dmpProjectEngineParamRequest.getParamId());
		}
		//参数名称
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamName())) {
			param.put("paramName", dmpProjectEngineParamRequest.getParamName());
		}
		//参数值
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamValue())) {
			param.put("paramValue", dmpProjectEngineParamRequest.getParamValue());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getRemark())) {
			param.put("remark", dmpProjectEngineParamRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectEngineParamRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectEngineParamRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectEngineParamRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectEngineParamRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectEngineParamRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectEngineParamRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectEngineParamRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectEngineParamRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectEngineParamRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectEngineParamRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectEngineParamRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectEngineParamRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectEngineParamRequest.getUpdateTimeEnd());
		}

		dmpProjectEngineParamMapper.delete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDelete(DmpProjectEngineParamRequest dmpProjectEngineParamRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectEngineParamRequest.getProjectParamId() != null) {
			param.put("projectParamId", dmpProjectEngineParamRequest.getProjectParamId());
		}
		//项目配置引擎关系主键
		if (dmpProjectEngineParamRequest.getConfigEngineId() != null) {
			param.put("configEngineId", dmpProjectEngineParamRequest.getConfigEngineId());
		}
		//引擎参数主键
		if (dmpProjectEngineParamRequest.getParamId() != null) {
			param.put("paramId", dmpProjectEngineParamRequest.getParamId());
		}
		//参数名称
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamName())) {
			param.put("paramName", dmpProjectEngineParamRequest.getParamName());
		}
		//参数值
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getParamValue())) {
			param.put("paramValue", dmpProjectEngineParamRequest.getParamValue());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getRemark())) {
			param.put("remark", dmpProjectEngineParamRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectEngineParamRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectEngineParamRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectEngineParamRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectEngineParamRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectEngineParamRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectEngineParamRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectEngineParamRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectEngineParamRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectEngineParamRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectEngineParamRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectEngineParamRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectEngineParamRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectEngineParamRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectEngineParamRequest.getUpdateTimeEnd());
		}

		dmpProjectEngineParamMapper.softDelete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectEngineParamService#addBatch(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectEngineParamVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectEngineParamBatch> addBatch(DmpProjectEngineParamBatch dmpProjectEngineParamBatch, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectEngineParamBatch> baseBeanResponse = new BaseBeanResponse<>();

		List<DmpProjectEngineParam> dmpProjectEngineParams = dmpProjectEngineParamBatch.getDmpProjectEngineParams();

		if (CollectionUtils.isEmpty(dmpProjectEngineParams)) {
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}

		dmpProjectEngineParams = dmpProjectEngineParams.stream().map(dmpProjectEngineParam -> {
			/*$*setProjectParamIdCodeReplace*$*/
			// 创建人
			try {
				dmpProjectEngineParam.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			// 创建时间
			dmpProjectEngineParam.setCreateTime(new Date());

			return dmpProjectEngineParam;
		}).collect(Collectors.toList());

		dmpProjectEngineParamMapper.insertBatch(dmpProjectEngineParams);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpProjectEngineParamBatch);

		return baseBeanResponse;
	}

	/**
	 *批量删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectEngineParamMapper.deleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/**
	 *批量软删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse softDeleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectEngineParamMapper.softDeleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

}
